@@ -84,7 +84,8 @@ METHOD knh__Int_opDiv__2(Ctx *ctx, knh_sfp_t *sfp)
 METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	knh_int_t i, n = ARG_int(sfp[0]);
+	size_t i;
+	knh_int_t n = ARG_int(sfp[0]);
 	for(i = 1; i < ac; i++) {
 		n += ARG_int(sfp[i]);
 	}
@@ -97,7 +98,8 @@ METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 METHOD knh__Int_opSub(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	knh_int_t i, n = ARG_int(sfp[0]);
+	size_t i;
+	knh_int_t n = ARG_int(sfp[0]);
 	for(i = 1; i < ac; i++) {
 		n -= ARG_int(sfp[i]);
 	}
@@ -110,7 +112,8 @@ METHOD knh__Int_opSub(Ctx *ctx, knh_sfp_t *sfp)
 METHOD knh__Int_opMul(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	knh_int_t i, n = ARG_int(sfp[0]);
+	size_t i;
+	knh_int_t n = ARG_int(sfp[0]);
 	for(i = 1; i < ac; i++) {
 		n *= ARG_int(sfp[i]);
 	}
@@ -123,7 +126,8 @@ METHOD knh__Int_opMul(Ctx *ctx, knh_sfp_t *sfp)
 METHOD knh__Int_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	knh_int_t i, n = ARG_int(sfp[0]);
+	size_t i;
+	knh_int_t n = ARG_int(sfp[0]);
 	for(i = 1; i < ac; i++) {
 		n /= ARG_int(sfp[i]);
 	}
@@ -220,7 +224,6 @@ METHOD knh__Int_opLnot(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-
 /* @method[CONST] Int! Int.opLshift(Int! n) */
 
 METHOD knh__Int_opLshift(Ctx *ctx, knh_sfp_t *sfp)
@@ -229,10 +232,9 @@ METHOD knh__Int_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
+/* @method[CONST] Int! Int.opRshift(Int! n) */
 
-/* @method[CONST] Int! Int.opRShift(Int! n) */
-
-METHOD knh__Int_opRShift(Ctx *ctx, knh_sfp_t *sfp)
+METHOD knh__Int_opRshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, ARG_int(sfp[0]) >> ARG_int(sfp[1]));
 }
@@ -367,7 +369,7 @@ void knh_Int__x(Ctx *ctx, Int *b, OutputStream *w, String *m)
 void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint_t n, int bits)
 {
 	knh_uint_t i, flag = 1 << (bits - 1);
-	for(i = 0; i < bits; i++) {
+	for(i = 0; i < (size_t)bits; i++) {
 		if(i > 0 && i % 8 == 0) {
 			knh_putc(ctx, w, ' ');
 		}
