@@ -178,7 +178,7 @@ char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid)
 void
 knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p)
 {
-	int i;
+	size_t i;
 	if(p.buf[p.len-1] == '.') {
 		p.len--;
 	}
