@@ -73,7 +73,7 @@ knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s)
 static
 knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim)
 {
-	int i, j;
+	size_t i, j;
 	for (i = 0; i <= base.len - delim.len; i++) {
 		j = 0;
 		while ((j < delim.len) && (base.buf[i+j] == delim.buf[j])) {
@@ -129,7 +129,7 @@ METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_sfp_t *v = sfp + 1;
 	knh_vargc_t ac = knh_sfp_argc(ctx, v);
-	int i;
+	size_t i;
 	knh_wbuf_t cb = knh_Context_wbuf(ctx);
 	knh_format(ctx, cb.w, METHODN__s, sfp[0].o, KNH_NULL);
 	for(i = 0; i < ac; i++) {
@@ -147,10 +147,10 @@ METHOD knh__String_opSub__2(Ctx *ctx, knh_sfp_t *sfp)
 	knh_bytes_t t = knh_String_tobytes(sfp[1].s);
 	knh_uchar_t c = t.buf[0];
 	knh_wbuf_t wbuf = knh_Context_wbuf(ctx);
-	knh_index_t i;
+	size_t i;
 	for(i = 0; i < base.len; i++) {
 		if(base.buf[i] == c) {
-			int j;
+			size_t j;
 			for(j = 1; j < t.len; j++) {
 				if(base.buf[i+j] != t.buf[j]) break;
 			}
@@ -194,7 +194,8 @@ METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp)
 
 	knh_wbuf_t wbuf = knh_Context_wbuf(ctx);
 
-	int s = 0, i, ch = os.buf[0];
+	size_t i;
+	int s = 0, ch = os.buf[0];
 	for(i = 0; i < base.len - os.len+1; i++) {
 		if(base.buf[i] == ch && knh_bytes_equals_(base, i, os)) {
 			knh_bytes_t hs = {base.buf + s, i - s};
@@ -293,7 +294,7 @@ METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp)
 							KNH_RETURN(ctx, sfp, TS_EMPTY);
 						}
 						//DBG2_P("idx=%d", idx);
-						if(mt != METHODN__empty && idx < ac) {
+						if(mt != METHODN__empty && (size_t)idx < ac) {
 							mtn = knh_bytes_last(mtn, 1);
 							if(knh_bytes_isOptionalMT(mtn)) {
 								knh_format(ctx, wbuf.w, mt, v[idx].o, UP(new_String(ctx, mtn, NULL)));
@@ -459,7 +460,7 @@ KNHAPI(String*) new_String_bconv(Ctx *ctx, String *s, f_bconv bconv)
 
 size_t bconv__toLower(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba)
 {
-	int i;
+	size_t i;
 	for(i = 0; i < t.len; i++) {
 		if(isupper(t.buf[i])) {
 			knh_Bytes_putc(ctx, ba, tolower(t.buf[i]));
@@ -484,7 +485,7 @@ METHOD knh__String_toLower(Ctx *ctx, knh_sfp_t *sfp)
 
 size_t bconv__toUpper(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba)
 {
-	int i;
+	size_t i;
 	for(i = 0; i < t.len; i++) {
 		if(islower(t.buf[i])) {
 			knh_Bytes_putc(ctx, ba, toupper(t.buf[i]));
@@ -577,7 +578,7 @@ void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m)
 	knh_putc(ctx, w, quote);
 	knh_bytes_t t = knh_String_tobytes(o);
 	knh_bytes_t sub = t;
-	knh_int_t i, s = 0;
+	size_t i, s = 0;
 	for(i = 0; i < o->size; i++) {
 		switch(t.buf[i]) {
 			case '\t' :
