@@ -455,7 +455,7 @@ void *knh_Compiler_asmmalloc(Ctx *ctx, Compiler *cpr, size_t size)
 {
 //	DEBUG("size=%d", (int)size);
 	size_t off = knh_Bytes_size(DP(cpr)->elf);
-	int i ;
+	size_t i ;
 	for(i = 0; i < size; i++) {
 		knh_Bytes_putc(ctx, DP(cpr)->elf, 0);
 	}
