@@ -55,7 +55,7 @@ knh_Compiler_typeinfer(Ctx *ctx, Compiler *cpr, knh_type_t type, char *varname)
 static
 knh_index_t knh_Compiler_cfield_add(Ctx *ctx, Compiler *cpr, knh_cfield_t *cf, size_t max, knh_flag_t flag, knh_type_t type, knh_fieldn_t fn, Object *value)
 {
-	knh_index_t idx;
+	size_t idx;
 	for(idx = 0; idx < max; idx++) {
 		if(cf[idx].fn == FIELDN_NONAME) {
 			cf[idx].flag = flag;
@@ -113,7 +113,7 @@ void knh_Compiler_declareVariable(Ctx *ctx, Compiler *cpr, knh_flag_t flag, knh_
 {
 	knh_index_t idx = knh_Compiler_cfield_add(ctx, cpr, DP(cpr)->vars, KONOHA_LOCALVAR_SIZE, flag, type, fn, value);
 	if(idx != -1 && (idx + 1) > DP(cpr)->vars_size) {
-		DP(cpr)->vars_size = idx + 1;
+		DP(cpr)->vars_size = (knh_ushort_t)(idx + 1);
 	}
 }
 
@@ -517,6 +517,7 @@ static
 void knh_StmtLET_addCONST(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level)
 {
 	int pe = KMSG_ESYNTAX;
+	knh_bytes_t cn = knh_Token_tobytes(DP(stmt)->tokens[LET_lvalue]);
 
 	if(level > 1) {
 		GOTO_PERROR(KMSG_NOTHERECONST);
@@ -528,7 +529,6 @@ void knh_StmtLET_addCONST(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, in
 		GOTO_PERROR(KMSG_NNCONST);
 	}
 
-	knh_bytes_t cn = knh_Token_tobytes(DP(stmt)->tokens[LET_lvalue]);
 	knh_index_t dotidx = knh_bytes_index(cn, '.');
 	Object *value = knh_Term_constValue(ctx, DP(stmt)->terms[LET_rvalue], CLASS_Any);
 
