@@ -57,7 +57,7 @@ void knh_Compiler_setGotoLabel(Ctx *ctx, Compiler *cpr, String *label)
 static
 knh_bool_t knh_Compiler_hasGotoLabel(Ctx *ctx, Compiler *cpr, knh_bytes_t label)
 {
-#if defined(KNH_DBGMODE)
+#if defined(KNH_DBGMODE2)
 	knh_ushort_t id = (knh_ushort_t)knh_DictIdx_add__b(ctx, DP(cpr)->labelIdDictIdx, label);
 	DBG2_P("LABEL %s id=%d", label.buf, (int)id);
 #endif
@@ -233,13 +233,15 @@ void knh_StmtIF_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_typ
 	knh_Stmt_terms_cmpl(ctx, stmt, 0, cpr, ns, CLASS_Boolean, 0 /*MC_FIRST*/);
 
 	if(knh_Term_isCONST(StmtIF_bool(stmt))) {
-		if(IS_TRUE(knh_Term_constValue(ctx, StmtIF_bool(stmt), CLASS_Any))) {
+		Object *v = knh_Term_constValue(ctx, StmtIF_bool(stmt), CLASS_Any);
+		if(IS_TRUE(v)) {
 			knh_Stmt_cmpls(ctx, StmtIF_truecase(stmt), cpr, ns, level + 1);
+			return;
 		}
-		else {
+		else if(IS_FALSE(v)){
 			knh_Stmt_cmpls(ctx, StmtIF_falsecase(stmt), cpr, ns, level + 1);
+			return;
 		}
-		return;
 	}
 
 	{
@@ -249,11 +251,16 @@ void knh_StmtIF_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_typ
 		knh_snprintf(lbend, sizeof(lbend), "_END_%d", knh_Compiler_llstep(cpr));
 
 		/* if */
-		if(knh_Term_get_type(StmtIF_bool(stmt)) == NNTYPE_Boolean) {
+		knh_type_t btype = knh_Term_get_type(ctx, cpr, StmtIF_bool(stmt));
+		if(btype == NNTYPE_Boolean) {
+			KNH_ASM_JMP_IFF(ctx, cpr, B(lbelse), StmtIF_bool(stmt));
+		}
+		else if(btype == TYPE_Any || btype == NNTYPE_Any || btype == TYPE_Boolean){
+			KNH_ASM_TYPECHK(ctx, cpr, NNTYPE_Boolean, StmtIF_bool(stmt));
 			KNH_ASM_JMP_IFF(ctx, cpr, B(lbelse), StmtIF_bool(stmt));
 		}
 		else {
-			KNH_ASM_JMP_IFFN(ctx, cpr, B(lbelse), StmtIF_bool(stmt));
+			knh_Compiler_perror(ctx, cpr, KMSG_ETYPEBOOL, "if(..)");
 		}
 		knh_Stmt_cmpls(ctx, StmtIF_truecase(stmt), cpr, ns, level + 1);
 		KNH_ASM_JMP(ctx, cpr, B(lbend));
@@ -277,21 +284,20 @@ void knh_StmtALT_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_ty
 		int i, size = DP(stmt)->size;
 		knh_type_t reqc = TYPE_UNMASK_NN(reqt), nnreqt = CLASS_TONNTYPE(reqc);
 
-		for(i = 0; i < size; i++) {
-			if(i < size - 1) {
-				knh_Stmt_terms_cmplpush(ctx, stmt, i, cpr, ns, reqc, level);
-				level = 0; /* isfirst = 1*/
-				KNH_ASM_JMP_IFNN__ebp(ctx, cpr, lbn, 0);
-			}
-			else {
-				knh_Stmt_terms_cmplpush(ctx, stmt, i, cpr, ns, nnreqt, level);
-				level = 0; /* isfirst = 1*/
+		for(i = 0; i < size - 1; i++) {
+			knh_Stmt_terms_cmplpush(ctx, stmt, i, cpr, ns, reqc, level);
+			level = 0; /* isfirst = 1*/
+			KNH_ASM_JMP_IFNN__ebp(ctx, cpr, lbn, 0);
+		}
+
+		knh_Stmt_terms_cmplpush(ctx, stmt, size - 1, cpr, ns, nnreqt, level);
+		level = 0;
+		/* isfirst = 1*/
 				//		if(needs_nullcheck) {
 				//			KNH_ASM_NULLCHK__ebp(ctx, cpr, 0);
 				//		}
-			}
-		}
 		KNH_ASM_LABEL__b(ctx, cpr, lbn);
+		DP(stmt)->type = nnreqt;
 	}
 }
 
@@ -302,24 +308,27 @@ void knh_StmtAND_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_ty
 	char bufl[32];
 	knh_snprintf(bufl, sizeof(bufl), "LL%3d", knh_Compiler_llstep(cpr));
 	{
-		knh_type_t  rtype = NNTYPE_Boolean;
 		knh_bytes_t lbn = B(bufl);
-		int i;
+		size_t i;
 		for(i = 0; i < DP(stmt)->size; i++) {
 			knh_Stmt_terms_cmplpush(ctx, stmt, i, cpr, ns, CLASS_Boolean, level);
 			level = 0; /* isfirst = 1*/
 			if(i + 1 < DP(stmt)->size) {
-				if(knh_Term_get_type(DP(stmt)->terms[i]) == NNTYPE_Boolean) {
+				knh_type_t btype = knh_Term_get_type(ctx, cpr, DP(stmt)->terms[i]);
+				if(btype == NNTYPE_Boolean) {
 					KNH_ASM_JMP_IFF__ebp(ctx, cpr, lbn, 0);
 				}
+				else if(btype == TYPE_Any || btype == NNTYPE_Any || btype == TYPE_Boolean){
+					KNH_ASM_TYPECHK__ebp(ctx, cpr, NNTYPE_Boolean, 0);
+					KNH_ASM_JMP_IFF(ctx, cpr, lbn, 0);
+				}
 				else {
-					KNH_ASM_JMP_IFFN__ebp(ctx, cpr, lbn, 0);
-					rtype = CLASS_Any;
+					knh_Compiler_perror(ctx, cpr, KMSG_ETYPEBOOL, ".. and ..");
 				}
 			}
 		}
 		KNH_ASM_LABEL__b(ctx, cpr, lbn);
-		DP(stmt)->type = rtype;
+		DP(stmt)->type = NNTYPE_Boolean;
 	}
 }
 
@@ -331,23 +340,26 @@ void knh_StmtOR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_typ
 	knh_snprintf(bufl, sizeof(bufl), "LL%3d", knh_Compiler_llstep(cpr));
 	{
 		knh_bytes_t lbn = B(bufl);
-		knh_type_t  rtype = NNTYPE_Boolean;
-		int i;
+		size_t i;
 		for(i = 0; i < DP(stmt)->size; i++) {
 			knh_Stmt_terms_cmplpush(ctx, stmt, i, cpr, ns, TYPE_Boolean, level);
 			level = 0; /* isfirst = 1*/
 			if(i + 1 < DP(stmt)->size) {
-				if(knh_Term_get_type(DP(stmt)->terms[i]) == NNTYPE_Boolean) {
-					KNH_ASM_JMP_IFT__ebp(ctx, cpr, lbn, 0);
+				knh_type_t btype = knh_Term_get_type(ctx, cpr, DP(stmt)->terms[i]);
+				if(btype == NNTYPE_Boolean) {
+					KNH_ASM_JMP_IFF__ebp(ctx, cpr, lbn, 0);
+				}
+				else if(btype == TYPE_Any || btype == NNTYPE_Any || btype == TYPE_Boolean){
+					KNH_ASM_TYPECHK__ebp(ctx, cpr, NNTYPE_Boolean, 0);
+					KNH_ASM_JMP_IFF(ctx, cpr, lbn, 0);
 				}
 				else {
-					KNH_ASM_JMP_IFTNN__ebp(ctx, cpr, lbn, 0);
-					rtype = CLASS_Any;
+					knh_Compiler_perror(ctx, cpr, KMSG_ETYPEBOOL, ".. or ..");
 				}
 			}
 		}
 		KNH_ASM_LABEL__b(ctx, cpr, lbn);
-		DP(stmt)->type = rtype;
+		DP(stmt)->type = NNTYPE_Boolean;
 	}
 }
 
@@ -367,13 +379,19 @@ void knh_StmtTRINARY_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, kn
 
 	knh_Stmt_terms_cmpl(ctx, stmt, 0, cpr, ns, TYPE_Boolean, level);
 
-	/* if */
-	if(knh_Term_get_type(StmtTRINARY_bool(stmt)) == NNTYPE_Boolean) {
+	knh_type_t btype = knh_Term_get_type(ctx, cpr, StmtTRINARY_bool(stmt));
+	if(btype == NNTYPE_Boolean) {
+		KNH_ASM_JMP_IFF(ctx, cpr, B(lbelse), StmtTRINARY_bool(stmt));
+	}
+	else if(btype == TYPE_Any || btype == NNTYPE_Any || btype == TYPE_Boolean){
+		KNH_ASM_TYPECHK(ctx, cpr, NNTYPE_Boolean, StmtTRINARY_bool(stmt));
 		KNH_ASM_JMP_IFF(ctx, cpr, B(lbelse), StmtTRINARY_bool(stmt));
 	}
 	else {
-		KNH_ASM_JMP_IFFN(ctx, cpr, B(lbend), StmtTRINARY_bool(stmt));
+		knh_Compiler_perror(ctx, cpr, KMSG_ETYPEBOOL, NULL);
+		return;
 	}
+
 	knh_Stmt_terms_cmplpush(ctx, stmt, 1, cpr, ns, reqt, 0 /* MC_FIRST */);
 	KNH_ASM_JMP(ctx, cpr, B(lbend));
 
@@ -382,8 +400,9 @@ void knh_StmtTRINARY_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, kn
 	knh_Stmt_terms_cmplpush(ctx, stmt, 2, cpr, ns, reqt, 0 /* MC_FIRST */);
 	KNH_ASM_LABEL__b(ctx, cpr, B(lbend));
 	{
+		TODO();
 		knh_type_t ttype = knh_Term_type(StmtTRINARY_tvalue(stmt));
-		knh_type_t ftype = knh_Term_type(StmtTRINARY_tvalue(stmt));
+		knh_type_t ftype = knh_Term_type(StmtTRINARY_fvalue(stmt));
 		DEBUG3("ttype=%s%s, ftype=%s%s", TYPEQN(ttype), TYPEQN(ftype));
 		if(ttype == ftype) {
 			if(ttype == reqt) {
@@ -429,20 +448,31 @@ void knh_StmtWHILE_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 	knh_Stmt_terms_cmpl(ctx, stmt, 0, cpr, ns, CLASS_Boolean, 0 /* MC_FIRST */);
 
 	if(knh_Term_isCONST(StmtWHILE_bool(stmt))) {
-		if(IS_TRUE(knh_Term_constValue(ctx, StmtWHILE_bool(stmt), CLASS_Any))) { /* infinite loop */
+		Object *v = knh_Term_constValue(ctx, StmtWHILE_bool(stmt), CLASS_Any);
+		if(IS_TRUE(v)) { /* infinite loop */
 			knh_Stmt_cmpls(ctx, StmtWHILE_loop(stmt), cpr, ns, level + 1);
 			KNH_ASM_JMP(ctx, cpr, knh_String_tobytes(label));
+			KNH_ASM_LABEL__b(ctx, cpr, B(lbend));
+			return ;
 		}
-		else {
-			KNH_ASM_JMP(ctx, cpr, B(lbend));
+		else if(IS_FALSE(v)) {
+//			KNH_ASM_JMP(ctx, cpr, B(lbend));
+//			KNH_ASM_LABEL__b(ctx, cpr, B(lbend));
+			return;
 		}
 	}
-	else { /* whilc(bool) .. */
-		if(knh_Term_get_type(StmtWHILE_bool(stmt)) == NNTYPE_Boolean) {
+
+	{ /* whilc(bool) .. */
+		knh_type_t btype = knh_Term_get_type(ctx, cpr, StmtWHILE_bool(stmt));
+		if(btype == NNTYPE_Boolean) {
+			KNH_ASM_JMP_IFF(ctx, cpr, B(lbend), StmtWHILE_bool(stmt));
+		}
+		else if(btype == TYPE_Any || btype == NNTYPE_Any || btype == TYPE_Boolean){
+			KNH_ASM_TYPECHK(ctx, cpr, NNTYPE_Boolean, StmtWHILE_bool(stmt));
 			KNH_ASM_JMP_IFF(ctx, cpr, B(lbend), StmtWHILE_bool(stmt));
 		}
 		else {
-			KNH_ASM_JMP_IFFN(ctx, cpr, B(lbend), StmtWHILE_bool(stmt));
+			knh_Compiler_perror(ctx, cpr, KMSG_ETYPEBOOL, "while(..)");
 		}
 		knh_Stmt_cmpls(ctx, StmtWHILE_loop(stmt), cpr, ns, level + 1);
 		KNH_ASM_JMP(ctx, cpr, knh_String_tobytes(label));
@@ -481,19 +511,30 @@ void knh_StmtDO_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_typ
 	knh_Stmt_cmpls(ctx, StmtDO_loop(stmt), cpr, ns, level + 1);
 
 	knh_Stmt_terms_cmpl(ctx, stmt, 1, cpr, ns, CLASS_Boolean, 0 /* MC_FIRST */);
+
 	if(knh_Term_isCONST(StmtDO_bool(stmt))) {
-		if(IS_TRUE(knh_Term_constValue(ctx, StmtDO_bool(stmt), CLASS_Any))) { /* infinite loop */
+		Object *v = knh_Term_constValue(ctx, StmtDO_bool(stmt), CLASS_Any);
+		if(IS_TRUE(v)) { /* infinite loop */
 			KNH_ASM_JMP(ctx, cpr, knh_String_tobytes(label));
+			KNH_ASM_LABEL__b(ctx, cpr, B(lbend));
+			return;
 		}
-		else {
+		else if(IS_FALSE(v)) {
+			KNH_ASM_LABEL__b(ctx, cpr, B(lbend));
+			return ;
 		}
 	}
-	else {
-		if(knh_Term_get_type(StmtDO_bool(stmt)) == NNTYPE_Boolean) {
+	{
+		knh_type_t btype = knh_Term_get_type(ctx, cpr, StmtDO_bool(stmt));
+		if(btype == NNTYPE_Boolean) {
+			KNH_ASM_JMP_IFT(ctx, cpr, knh_String_tobytes(label), StmtDO_bool(stmt));
+		}
+		else if(btype == TYPE_Any || btype == NNTYPE_Any || btype == TYPE_Boolean){
+			KNH_ASM_TYPECHK(ctx, cpr, NNTYPE_Boolean, StmtDO_bool(stmt));
 			KNH_ASM_JMP_IFT(ctx, cpr, knh_String_tobytes(label), StmtDO_bool(stmt));
 		}
 		else {
-			KNH_ASM_JMP_IFTNN(ctx, cpr, knh_String_tobytes(label), StmtDO_bool(stmt));
+			knh_Compiler_perror(ctx, cpr, KMSG_ETYPEBOOL, "while(..)");
 		}
 	}
 	/* end */
@@ -511,7 +552,7 @@ String *knh_Term_getLabel(Term *tm, String *label)
 	if(IS_String(DP(tk)->data)) {
 		return (String*)DP(tk)->data;
 	}
-	DEBUG3("token tt=%s", knh_token_tochar(SP(tk)->tt));
+	//DEBUG3("token tt=%s", knh_token_tochar(SP(tk)->tt));
 	return label;
 }
 
@@ -531,7 +572,7 @@ void knh_StmtCONTINUE_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, k
 	}
 	if(DP(stmt)->size == 1) {
 		label = knh_Term_getLabel(StmtCONTINUE_label(stmt), label);
-		DEBUG3("continue %s", knh_String_tochar(label));
+		//DEBUG3("continue %s", knh_String_tochar(label));
 	}
 
 	if(knh_Compiler_hasBreakLabel(ctx, cpr, knh_String_tobytes(label))) {
@@ -559,7 +600,7 @@ void knh_StmtBREAK_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 	}
 	if(DP(stmt)->size == 1) {
 		label = knh_Term_getLabel(StmtBREAK_label(stmt), label);
-		DEBUG3("break %s", knh_String_tochar(label));
+		//DEBUG3("break %s", knh_String_tochar(label));
 	}
 	if(knh_Compiler_hasBreakLabel(ctx, cpr, knh_String_tobytes(label))) {
 		char lb[LABEL_BUFSIZ];
@@ -622,7 +663,7 @@ void knh_StmtFOR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_ty
 	char lbend[LABEL_BUFSIZ];
 	String *label = knh_Compiler_lstack_label(ctx, cpr);
 	KNH_ASSERT(label != NULL);
-	DEBUG3("for label='%s'", knh_String_tochar(label));
+	//DEBUG3("for label='%s'", knh_String_tochar(label));
 	//KNH_ASM_LABEL__b(ctx, cpr, knh_String_tobytes(label));
 
 	/* i = 1 part */
@@ -642,20 +683,31 @@ void knh_StmtFOR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_ty
 	knh_Stmt_terms_cmpl(ctx, stmt, 1, cpr, ns, CLASS_Boolean, 0 /* MC_FIRST */);
 
 	if(knh_Term_isCONST(StmtFOR_bool(stmt))) {
-		if(IS_TRUE(knh_Term_constValue(ctx, StmtFOR_bool(stmt), CLASS_Any))) { /* infinite loop */
+		Object *v = knh_Term_constValue(ctx, StmtFOR_bool(stmt), CLASS_Any);
+		if(IS_TRUE(v)) { /* infinite loop */
 			knh_Stmt_cmpls(ctx, StmtFOR_loop(stmt), cpr, ns, level + 1);
 			KNH_ASM_JMP(ctx, cpr, knh_String_tobytes(label));  /* GOTO CONTINUE */
+			KNH_ASM_LABEL__b(ctx, cpr, B(lbend));
+			return;
 		}
-		else {
+		else if(IS_FALSE(v)) {
 			KNH_ASM_JMP(ctx, cpr, B(lbend));
+			KNH_ASM_LABEL__b(ctx, cpr, B(lbend));
+			return ;
 		}
 	}
-	else { /* whilc(bool) .. */
-		if(knh_Term_get_type(StmtFOR_bool(stmt)) == NNTYPE_Boolean) {
+
+	{ /* whilc(bool) .. */
+		knh_type_t btype = knh_Term_get_type(ctx, cpr, StmtFOR_bool(stmt));
+		if(btype == NNTYPE_Boolean) {
 			KNH_ASM_JMP_IFF(ctx, cpr, B(lbend), StmtFOR_bool(stmt));
 		}
+		else if(btype == TYPE_Any || btype == NNTYPE_Any || btype == TYPE_Boolean){
+			KNH_ASM_TYPECHK(ctx, cpr, NNTYPE_Boolean, StmtFOR_bool(stmt));
+			KNH_ASM_JMP_IFF(ctx, cpr, knh_String_tobytes(label), StmtFOR_bool(stmt));
+		}
 		else {
-			KNH_ASM_JMP_IFFN(ctx, cpr, B(lbend), StmtFOR_bool(stmt));
+			knh_Compiler_perror(ctx, cpr, KMSG_ETYPEBOOL, "for(;..;)");
 		}
 		knh_Stmt_cmpls(ctx, StmtFOR_loop(stmt), cpr, ns, level + 1);
 		KNH_ASM_JMP(ctx, cpr, knh_String_tobytes(label));
