@@ -170,7 +170,7 @@ knh_class_t knh_Token_toclass(Ctx *ctx, Token *o, knh_class_t defc, NameSpace *n
 int knh_Token_isLCONSTN(Token *tk)
 {
 	knh_bytes_t t = knh_Token_tobytes(tk);
-	int i;
+	size_t i;
 	for(i = 0; i < t.len; i++) {
 		if(islower(t.buf[i])) return 0;
 	}
@@ -295,7 +295,7 @@ knh_int_t knh_Token_toint(Ctx *ctx, Token *o)
 {
 	knh_bytes_t t = knh_Token_tobytes(o);
 	knh_uint_t n = 0, prev = 0, base = 10;
-	int i = 0;
+	size_t i = 0;
 
 	if(t.len > 1) {
 		if(t.buf[0] == '0') {
@@ -336,7 +336,7 @@ knh_int_t knh_Token_toint(Ctx *ctx, Token *o)
 			return 0;
 		}
 	}
-	if(t.buf[0] == '-') return (knh_int_t)-n;
+	if(t.buf[0] == '-') return -((knh_int_t)n);
 	return (knh_int_t)n;
 }
 
@@ -347,7 +347,7 @@ knh_int64_t knh_Token_toint64(Ctx *ctx, Token *o)
 {
 	knh_bytes_t t = knh_Token_tobytes(o);
 	knh_int64_t n = 0, prev = 0, base = 10;
-	int i = 0;
+	size_t i = 0;
 
 	if(t.len > 1) {
 		if(t.buf[0] == '0') {
@@ -388,7 +388,7 @@ knh_int64_t knh_Token_toint64(Ctx *ctx, Token *o)
 			return 0;
 		}
 	}
-	if(t.buf[0] == '-') return (knh_int64_t)-n;
+	if(t.buf[0] == '-') return -((knh_int64_t)n);
 	return (knh_int64_t)n;
 }
 
@@ -403,7 +403,7 @@ knh_float_t knh_Token_tofloat(Ctx *ctx, Token *o)
 		return (knh_float_t)n;
 	}
 	else {
-		int i = 0, c = 1;
+		size_t i = 0, c = 1;
 		knh_float_t v = 0.0, prev = 0.0;
 
 		if(t.buf[0] == '-') i = 1;
@@ -451,7 +451,8 @@ static
 knh_class_t knh_Token_tagcNUM(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns)
 {
 	knh_bytes_t t = knh_Token_tobytes(o), tag = STEXT("");
-	int i = 1, ishex = 0;
+	size_t i = 1;
+	int ishex = 0;
 	if(t.buf[0] == '0' && (t.buf[1] == 'x' || t.buf[1] == 'b')) {
 		i = 2;
 		ishex = 1;
@@ -505,7 +506,7 @@ knh_class_t knh_Token_tagcNUM(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *n
 static
 knh_class_t knh_bytes_guessNUMcid(Ctx *ctx, knh_bytes_t t)
 {
-	int i;
+	size_t i;
 	for(i = 1; i < t.len; i++) {
 		if(t.buf[i] == '_') {
 #ifdef CLASS_Decimal
