@@ -113,22 +113,23 @@ knh_Token_perror(Ctx *ctx, Token *o, int pe)
 	}
 }
 
-/* ------------------------------------------------------------------------ */
-
-void
-knh_tokens_perror(Ctx *ctx, knh_tokens_t *tc, int pe)
-{
-	Token *tk = knh_tokens_curToken(tc);
-	knh_perror(ctx, SP(tk)->fileid, (int)SP(tk)->line, pe, knh_Token_tochar(tk));
-}
+///* ------------------------------------------------------------------------ */
+//
+//void
+//knh_tokens_perror(Ctx *ctx, knh_tokens_t *tc, int pe)
+//{
+//	Token *tk = knh_tokens_curToken(tc);
+//	knh_perror(ctx, SP(tk)->fileid, (int)SP(tk)->line, pe, knh_Token_tochar(tk));
+//}
 
 /* ------------------------------------------------------------------------ */
 
-void knh_Stmt_perror(Ctx *ctx, Stmt *b, knh_tokens_t *tc, int pe)
+void knh_Stmt_tokens_perror(Ctx *ctx, Stmt *o, knh_tokens_t *tc, int pe)
 {
 	Token *tk = knh_tokens_curToken(tc);
 	knh_perror(ctx, SP(tk)->fileid, (int)SP(tk)->line, pe, knh_Token_tochar(tk));
-	knh_Stmt_add_ERR(ctx, b, tk);
+	SP(tk)->tt = TT_ERR;
+	knh_Stmt_add(ctx, o, TM(tk));
 	knh_tokens_nextStmt(tc);
 }
 
@@ -136,39 +137,48 @@ void knh_Stmt_perror(Ctx *ctx, Stmt *b, knh_tokens_t *tc, int pe)
 
 Stmt *new_StmtERR(Ctx *ctx, knh_tokens_t *tc)
 {
-	Stmt *b = new_Stmt(ctx, 0, STT_ERR);
-	knh_Stmt_add(ctx, b, TM(knh_tokens_curToken(tc)));
+	Stmt *stmt = new_Stmt(ctx, 0, STT_ERR);
+	knh_Stmt_add(ctx, stmt, TM(knh_tokens_curToken(tc)));
 	knh_tokens_nextStmt(tc);
-	return b;
+	return stmt;
+}
+
+/* ------------------------------------------------------------------------ */
+
+void knh_Stmt_perror(Ctx *ctx, Stmt *o, int pe, Token *tk)
+{
+	if(tk == NULL || !IS_Token(tk)) {
+		knh_perror(ctx, SP(o)->fileid, (int)SP(o)->line, pe, NULL);
+		if(knh_message_type(pe) == 1) {
+			SP(o)->stt = STT_ERR;
+		}
+	}
+	else {
+		knh_Token_perror(ctx, tk, pe);
+		SP(tk)->tt = TT_ERR;
+		knh_Stmt_add(ctx, o, TM(tk));
+	}
 }
 
 /* ======================================================================== */
-/* [STMT] */
+/* [Compiler] */
 
 void
 knh_Compiler_perror(Ctx *ctx, Compiler *cpr, int pe, char *msg)
 {
 	knh_perror(ctx, DP(cpr)->fileid, (int)DP(cpr)->line, pe, msg);
+	if(knh_message_type(pe) == 1) {
+		knh_Compiler_setCancelled(cpr, 1);
+	}
 }
 
-/* ======================================================================== */
-/* [STMT] */
+/* ------------------------------------------------------------------------ */
 
 void
-knh_notice_TypeInf(Ctx *ctx, knh_fileid_t fileid, int line, char *msg, knh_type_t type)
+knh_Compiler_assert(Ctx *ctx, Compiler *cpr, int c)
 {
-	if(type == CLASS_Any || type == NNTYPE_Any) {
-		knh_perror(ctx, fileid, line, KMSG_WTYPEINF, msg);
-	}else if(knh_Context_isVerbose(ctx)) {
-//		char buf[512];
-//		OutputStream *w = KNH_STDOUT;
-//		knh_snprintf(buf, sizeof(buf), "%s:%d (%s): ", FILEIDN(fileid), line, knh_message_text(KMSG_TYPEINF));
-//		knh_print(ctx, w, B(buf));
-//		knh_write__s(ctx, w, msg);
-//		knh_write__s(ctx, w, " ..> ");
-//		knh_write__type(ctx, w, type);
-//		knh_write_EOL(ctx, w);
-	}
+	knh_perror(ctx, DP(cpr)->fileid, (int)DP(cpr)->line, KMSG_EABORT, NULL);
+	knh_Compiler_setCancelled(cpr, 1);
 }
 
 /* ------------------------------------------------------------------------ */
