@@ -45,8 +45,8 @@ extern "C" {
 #define KNH_FLAG_MMF_AFFINE (KNH_FLAG_MMF_SIGNIFICANT|KNH_FLAG_MMF_SYNONYM|KNH_FLAG_MMF_TOTAL|KNH_FLAG_MMF_CONST)
 #define knh_Array_n(a,n)      (a)->list[(n)]
 #define knh_Array_size(a)     (a)->size
-#define IS_TRUE(o)             (o != KNH_FALSE && IS_NOTNULL(o))
-#define IS_FALSE(o)            (o == KNH_FALSE || IS_NULL(o))
+#define IS_TRUE(o)         (o == KNH_TRUE)
+#define IS_FALSE(o)        (o == KNH_FALSE)
 #define BOOL_ISTRUE(o)         (o == KNH_TRUE)
 #define BOOL_ISFALSE(o)        (o == KNH_FALSE)
 #define new_Boolean(ctx,b)     ((b) ? KNH_TRUE : KNH_FALSE)
@@ -90,10 +90,7 @@ extern "C" {
 #define KNH_STDOUT         (((Context*)ctx)->out)
 #define KNH_STDERR         (((Context*)ctx)->err)
 #define knh_DictIdx_struct_copy   NULL
-#define knh_DictMap_put(ctx,b,k,v) knh_DictMap_set(ctx,b,k,v)
-#define knh_DictMap_put(ctx,b,k,v) knh_DictMap_set(ctx,b,k,v)
-#define knh_DictMap_String__   knh_DictMap_Iterator
-#define knh_DictSet_put(ctx,b,k,v) knh_DictSet_set(ctx,b,k,v)
+#define new_DictSet(ctx, c)   new_DictSet0(ctx, c)
 #define EXPT_newid            ((knh_expt_t)0)
 #define EXPT_Exception        ((knh_expt_t)1)
 #define EXPT_NoSuchException  ((knh_expt_t)2)
