@@ -51,92 +51,92 @@ extern "C" {
 #define KMSG_WARNING                    5
 #define KMSG_INFO                       6
 #define KMSG_ESYNTAX                    7
-#define KMSG_EFORGET_PARENTHESIS        8
-#define KMSG_EMISMATCH                  9
-#define KMSG_WUNCLOSED                  10
-#define KMSG_WASCII                     11
-#define KMSG_WEOF                       12
-#define KMSG_WINDENT                    13
-#define KMSG_WSEMICOLON                 14
-#define KMSG_IGSTMT                     15
-#define KMSG_ETOKEN                     16
-#define KMSG_ELENGTH                    17
-#define KMSG_WCLASSN                    18
-#define KMSG_WCONSTN                    19
-#define KMSG_WCMETHODN                  20
-#define KMSG_WNAME                      21
-#define KMSG_WIGNORED                   22
-#define KMSG_TEXPTN                     23
-#define KMSG_TNSNAME                    24
-#define KMSG_TFURN                      25
-#define KMSG_TCURN                      26
-#define KMSG_TNSCLASSN                  27
-#define KMSG_TTYPEN                     28
-#define KMSG_TMETHODN                   29
-#define KMSG_TCLASSTN                   30
-#define KMSG_TSTR                       31
-#define KMSG_TVARN                      32
-#define KMSG_TCLASSN                    33
-#define KMSG_TARGS                      34
-#define KMSG_TNAME                      35
-#define KMSG_TCMETHODN                  36
-#define KMSG_TMT                        37
-#define KMSG_TANY                       38
-#define KMSG_TSTMT1                     39
-#define KMSG_TPEXPR                     40
-#define KMSG_TCATCHPARAM                41
-#define KMSG_ELVALUE                    42
-#define KMSG_WTYPEINF                   43
-#define KMSG_NOTHERECONST               44
-#define KMSG_NOTHERECLASSCONST          45
-#define KMSG_NNCONST                    46
-#define KMSG_DUPCONST                   47
-#define KMSG_ENEXTPREV                  48
-#define KMSG_EEMPTYEXPR                 49
-#define KMSG_ETRINARY                   50
-#define KMSG_EBUILTINFUNC               51
-#define KMSG_EPSTMT3                    52
-#define KMSG_EPEACH                     53
-#define KMSG_WLET                       54
-#define KMSG_WEMPTY                     55
-#define KMSG_WTRUEFALSE                 56
-#define KMSG_USCRIPT                    57
-#define KMSG_UUOPTION                   58
-#define KMSG_UURN                       59
-#define KMSG_UPACKAGE                   60
-#define KMSG_UCONSTN                    61
-#define KMSG_UVARN                      62
-#define KMSG_USYSTEMVARN                63
-#define KMSG_UCLASSN                    64
-#define KMSG_UTAG                       65
-#define KMSG_UTYPEN                     66
-#define KMSG_UMETHODN                   67
-#define KMSG_UFUNCN                     68
-#define KMSG_ULABEL                     69
-#define KMSG_UOP                        70
-#define KMSG_UOP1                       71
-#define KMSG_UOP2                       72
-#define KMSG_UNEW                       73
-#define KMSG_UMAP                       74
-#define KMSG_INTOVERFLOW                75
-#define KMSG_FLOATOVERFLOW              76
-#define KMSG_INT64OVERFLOW              77
-#define KMSG_ETOOFEWPARAMS              78
-#define KMSG_WTOOMANYPARAMS             79
-#define KMSG_EOP2                       80
-#define KMSG_EOPCMP                     81
-#define KMSG_ENULLPARAM                 82
-#define KMSG_WNULLPARAM                 83
-#define KMSG_ETYPEPARAM                 84
-#define KMSG_ENULLRETURN                85
-#define KMSG_WNULLRETURN                86
-#define KMSG_ETYPERETURN                87
-#define KMSG_ENULLLET                   88
-#define KMSG_ENULL                      89
-#define KMSG_WNULLLET                   90
-#define KMSG_WNULL                      91
-#define KMSG_ETYPELET                   92
-#define KMSG_ETYPE                      93
+#define KMSG_EABORT                     8
+#define KMSG_EFORGET_PARENTHESIS        9
+#define KMSG_EMISMATCH                  10
+#define KMSG_WUNCLOSED                  11
+#define KMSG_WASCII                     12
+#define KMSG_WEOF                       13
+#define KMSG_WINDENT                    14
+#define KMSG_WSEMICOLON                 15
+#define KMSG_IGSTMT                     16
+#define KMSG_ETOKEN                     17
+#define KMSG_ELENGTH                    18
+#define KMSG_WCLASSN                    19
+#define KMSG_WCONSTN                    20
+#define KMSG_WCMETHODN                  21
+#define KMSG_WNAME                      22
+#define KMSG_WIGNORED                   23
+#define KMSG_TEXPTN                     24
+#define KMSG_TNSNAME                    25
+#define KMSG_TFURN                      26
+#define KMSG_TCURN                      27
+#define KMSG_TNSCLASSN                  28
+#define KMSG_TTYPEN                     29
+#define KMSG_TMETHODN                   30
+#define KMSG_TCLASSTN                   31
+#define KMSG_TSTR                       32
+#define KMSG_TVARN                      33
+#define KMSG_TCLASSN                    34
+#define KMSG_TARGS                      35
+#define KMSG_TNAME                      36
+#define KMSG_TCMETHODN                  37
+#define KMSG_TMT                        38
+#define KMSG_TANY                       39
+#define KMSG_TSTMT1                     40
+#define KMSG_TPEXPR                     41
+#define KMSG_TCATCHPARAM                42
+#define KMSG_ELVALUE                    43
+#define KMSG_WTYPEINF                   44
+#define KMSG_NOTHERECONST               45
+#define KMSG_NOTHERECLASSCONST          46
+#define KMSG_NNCONST                    47
+#define KMSG_DUPCONST                   48
+#define KMSG_ENEXTPREV                  49
+#define KMSG_EBUILTINFUNC               50
+#define KMSG_EPSTMT3                    51
+#define KMSG_EPEACH                     52
+#define KMSG_WLET                       53
+#define KMSG_WEMPTY                     54
+#define KMSG_WTRUEFALSE                 55
+#define KMSG_USCRIPT                    56
+#define KMSG_UUOPTION                   57
+#define KMSG_UURN                       58
+#define KMSG_UPACKAGE                   59
+#define KMSG_UCONSTN                    60
+#define KMSG_UVARN                      61
+#define KMSG_USYSTEMVARN                62
+#define KMSG_UCLASSN                    63
+#define KMSG_UTAG                       64
+#define KMSG_UTYPEN                     65
+#define KMSG_UMETHODN                   66
+#define KMSG_UFUNCN                     67
+#define KMSG_ULABEL                     68
+#define KMSG_UOP                        69
+#define KMSG_UOP1                       70
+#define KMSG_UOP2                       71
+#define KMSG_UNEW                       72
+#define KMSG_UMAP                       73
+#define KMSG_INTOVERFLOW                74
+#define KMSG_FLOATOVERFLOW              75
+#define KMSG_INT64OVERFLOW              76
+#define KMSG_ETOOFEWPARAMS              77
+#define KMSG_WTOOMANYPARAMS             78
+#define KMSG_EOP2                       79
+#define KMSG_EOPCMP                     80
+#define KMSG_ENULLPARAM                 81
+#define KMSG_WNULLPARAM                 82
+#define KMSG_ETYPEPARAM                 83
+#define KMSG_ENULLRETURN                84
+#define KMSG_WNULLRETURN                85
+#define KMSG_ETYPERETURN                86
+#define KMSG_ENULLLET                   87
+#define KMSG_ENULL                      88
+#define KMSG_WNULLLET                   89
+#define KMSG_WNULL                      90
+#define KMSG_ETYPELET                   91
+#define KMSG_ETYPE                      92
+#define KMSG_ETYPEBOOL                  93
 #define KMSG_WDUPFUNCNAME               94
 #define KMSG_USCLASSFUNC                95
 #define KMSG_IGNNTYPE                   96
