@@ -154,7 +154,7 @@ knh_bytes_t knh_bytes_offlen(knh_bytes_t t, size_t off, size_t len);
 knh_bytes_t knh_bytes_trim(knh_bytes_t t, knh_int_t ch);
 knh_int_t knh_bytes_toint(knh_bytes_t t);
 knh_float_t knh_bytes_tofloat(knh_bytes_t t);
-knh_int_t knh_bytes_toint64(knh_bytes_t t);
+knh_int64_t knh_bytes_toint64(knh_bytes_t t);
 /* ../class/konoha/knh_BytesConv.c */
 void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
 void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, f_traverse ftr);
@@ -484,7 +484,7 @@ METHOD knh__Int_opLor(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opXor(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opLnot(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opRShift(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Int_opRshift(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opNext(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opPrev(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_getSize(Ctx *ctx, knh_sfp_t *sfp);
@@ -1050,6 +1050,9 @@ char * knh_format_homepath(char *buf, size_t bufsiz);
 /* ../konoha/deps/macosx/filesystem__macosx.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
+/* ../konoha/deps/tb/filesystem__tb.c */
+char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
+char * knh_format_homepath(char *buf, size_t bufsiz);
 /* ../konoha/deps/win32/filesystem__win32.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
