@@ -108,33 +108,29 @@ extern "C" {
 #define ASMC_JMP_IFF__SFP               ((knhvm_opcode_t)69)
 #define ASMC_JMP_IFF__OFP               ((knhvm_opcode_t)70)
 #define ASMC_JMP_IFF__OIDX              ((knhvm_opcode_t)71)
-#define ASMC_JMP_IFTNN__EBP             ((knhvm_opcode_t)72)
-#define ASMC_JMP_IFTNN__SFP             ((knhvm_opcode_t)73)
-#define ASMC_JMP_IFTNN__OFP             ((knhvm_opcode_t)74)
-#define ASMC_JMP_IFTNN__OIDX            ((knhvm_opcode_t)75)
-#define ASMC_JMP_IFFN__EBP              ((knhvm_opcode_t)76)
-#define ASMC_JMP_IFFN__SFP              ((knhvm_opcode_t)77)
-#define ASMC_JMP_IFFN__OFP              ((knhvm_opcode_t)78)
-#define ASMC_JMP_IFFN__OIDX             ((knhvm_opcode_t)79)
-#define ASMC_JMP_IFNN__EBP              ((knhvm_opcode_t)80)
-#define ASMC_JMP_IFNN__SFP              ((knhvm_opcode_t)81)
-#define ASMC_JMP_IFNN__OFP              ((knhvm_opcode_t)82)
-#define ASMC_JMP_IFNN__OIDX             ((knhvm_opcode_t)83)
-#define ASMC_NEXT                       ((knhvm_opcode_t)84)
-#define ASMC_MAPNEXT                    ((knhvm_opcode_t)85)
-#define ASMC_SMAPNEXT                   ((knhvm_opcode_t)86)
-#define ASMC_TRY_BEGIN                  ((knhvm_opcode_t)87)
-#define ASMC_TRY_END                    ((knhvm_opcode_t)88)
-#define ASMC_CATCH                      ((knhvm_opcode_t)89)
-#define ASMC_THROW__EBP                 ((knhvm_opcode_t)90)
-#define ASMC_THROW__SFP                 ((knhvm_opcode_t)91)
-#define ASMC_THROW__OBJ                 ((knhvm_opcode_t)92)
-#define ASMC_PRINT__EBP                 ((knhvm_opcode_t)93)
-#define ASMC_PRINT__SFP                 ((knhvm_opcode_t)94)
-#define ASMC_PRINT__OFP                 ((knhvm_opcode_t)95)
-#define ASMC_PRINT__OBJ                 ((knhvm_opcode_t)96)
-#define ASMC_PRINT__OIDX                ((knhvm_opcode_t)97)
-#define ASMC_NOP                        ((knhvm_opcode_t)98)
+#define ASMC_JMP_IFN__EBP               ((knhvm_opcode_t)72)
+#define ASMC_JMP_IFN__SFP               ((knhvm_opcode_t)73)
+#define ASMC_JMP_IFN__OFP               ((knhvm_opcode_t)74)
+#define ASMC_JMP_IFN__OIDX              ((knhvm_opcode_t)75)
+#define ASMC_JMP_IFNN__EBP              ((knhvm_opcode_t)76)
+#define ASMC_JMP_IFNN__SFP              ((knhvm_opcode_t)77)
+#define ASMC_JMP_IFNN__OFP              ((knhvm_opcode_t)78)
+#define ASMC_JMP_IFNN__OIDX             ((knhvm_opcode_t)79)
+#define ASMC_NEXT                       ((knhvm_opcode_t)80)
+#define ASMC_MAPNEXT                    ((knhvm_opcode_t)81)
+#define ASMC_SMAPNEXT                   ((knhvm_opcode_t)82)
+#define ASMC_TRY_BEGIN                  ((knhvm_opcode_t)83)
+#define ASMC_TRY_END                    ((knhvm_opcode_t)84)
+#define ASMC_CATCH                      ((knhvm_opcode_t)85)
+#define ASMC_THROW__EBP                 ((knhvm_opcode_t)86)
+#define ASMC_THROW__SFP                 ((knhvm_opcode_t)87)
+#define ASMC_THROW__OBJ                 ((knhvm_opcode_t)88)
+#define ASMC_PRINT__EBP                 ((knhvm_opcode_t)89)
+#define ASMC_PRINT__SFP                 ((knhvm_opcode_t)90)
+#define ASMC_PRINT__OFP                 ((knhvm_opcode_t)91)
+#define ASMC_PRINT__OBJ                 ((knhvm_opcode_t)92)
+#define ASMC_PRINT__OIDX                ((knhvm_opcode_t)93)
+#define ASMC_NOP                        ((knhvm_opcode_t)94)
 
 /* ------------------------------------------------------------------------ */
 #ifndef METHODN__k
@@ -230,16 +226,11 @@ void KNH_ASM_JMP_IFF__ebp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ebp_t a2)
 void KNH_ASM_JMP_IFF__sfp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_sfp_t a2);
 void KNH_ASM_JMP_IFF__ofp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ofp_t a2);
 void KNH_ASM_JMP_IFF__OIDX(Ctx *ctx, Compiler *o, knh_bytes_t a1, Object* a2, knhvm_u1_t a3);
-void KNH_ASM_JMP_IFTNN(Ctx *ctx, Compiler *o, knh_bytes_t a1, Term *v);
-void KNH_ASM_JMP_IFTNN__ebp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ebp_t a2);
-void KNH_ASM_JMP_IFTNN__sfp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_sfp_t a2);
-void KNH_ASM_JMP_IFTNN__ofp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ofp_t a2);
-void KNH_ASM_JMP_IFTNN__OIDX(Ctx *ctx, Compiler *o, knh_bytes_t a1, Object* a2, knhvm_u1_t a3);
-void KNH_ASM_JMP_IFFN(Ctx *ctx, Compiler *o, knh_bytes_t a1, Term *v);
-void KNH_ASM_JMP_IFFN__ebp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ebp_t a2);
-void KNH_ASM_JMP_IFFN__sfp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_sfp_t a2);
-void KNH_ASM_JMP_IFFN__ofp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ofp_t a2);
-void KNH_ASM_JMP_IFFN__OIDX(Ctx *ctx, Compiler *o, knh_bytes_t a1, Object* a2, knhvm_u1_t a3);
+void KNH_ASM_JMP_IFN(Ctx *ctx, Compiler *o, knh_bytes_t a1, Term *v);
+void KNH_ASM_JMP_IFN__ebp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ebp_t a2);
+void KNH_ASM_JMP_IFN__sfp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_sfp_t a2);
+void KNH_ASM_JMP_IFN__ofp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ofp_t a2);
+void KNH_ASM_JMP_IFN__OIDX(Ctx *ctx, Compiler *o, knh_bytes_t a1, Object* a2, knhvm_u1_t a3);
 void KNH_ASM_JMP_IFNN(Ctx *ctx, Compiler *o, knh_bytes_t a1, Term *v);
 void KNH_ASM_JMP_IFNN__ebp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_ebp_t a2);
 void KNH_ASM_JMP_IFNN__sfp(Ctx *ctx, Compiler *o, knh_bytes_t a1, knhvm_sfp_t a2);
@@ -1457,16 +1448,16 @@ typedef struct {
 	knhvm_opcode_t code;
 	knhvm_addr_t a1;
 	knhvm_ebp_t a2;
-} knh_asmc_jmp_iftnn_ebp_t;
+} knh_asmc_jmp_ifn_ebp_t;
 
 typedef struct {
 	knhvm_opcode_t code;
 	knhvm_addr_t a1;
 	knhvm_ebp_t a2;
 	void *w;
-} knh_asmc_jmp_iftnn_ebp_tw;
+} knh_asmc_jmp_ifn_ebp_tw;
 
-#define KNH_ASMC_JMP_IFTNN_ebp_SIZ  (sizeof(knh_asmc_jmp_iftnn_ebp_tw)-sizeof(void*))
+#define KNH_ASMC_JMP_IFN_ebp_SIZ  (sizeof(knh_asmc_jmp_ifn_ebp_tw)-sizeof(void*))
 
 /* ------------------------------------------------------------------------ */
 
@@ -1474,16 +1465,16 @@ typedef struct {
 	knhvm_opcode_t code;
 	knhvm_addr_t a1;
 	knhvm_sfp_t a2;
-} knh_asmc_jmp_iftnn_sfp_t;
+} knh_asmc_jmp_ifn_sfp_t;
 
 typedef struct {
 	knhvm_opcode_t code;
 	knhvm_addr_t a1;
 	knhvm_sfp_t a2;
 	void *w;
-} knh_asmc_jmp_iftnn_sfp_tw;
+} knh_asmc_jmp_ifn_sfp_tw;
 
-#define KNH_ASMC_JMP_IFTNN_sfp_SIZ  (sizeof(knh_asmc_jmp_iftnn_sfp_tw)-sizeof(void*))
+#define KNH_ASMC_JMP_IFN_sfp_SIZ  (sizeof(knh_asmc_jmp_ifn_sfp_tw)-sizeof(void*))
 
 /* ------------------------------------------------------------------------ */
 
@@ -1491,16 +1482,16 @@ typedef struct {
 	knhvm_opcode_t code;
 	knhvm_addr_t a1;
 	knhvm_ofp_t a2;
-} knh_asmc_jmp_iftnn_ofp_t;
+} knh_asmc_jmp_ifn_ofp_t;
 
 typedef struct {
 	knhvm_opcode_t code;
 	knhvm_addr_t a1;
 	knhvm_ofp_t a2;
 	void *w;
-} knh_asmc_jmp_iftnn_ofp_tw;
+} knh_asmc_jmp_ifn_ofp_tw;
 
-#define KNH_ASMC_JMP_IFTNN_ofp_SIZ  (sizeof(knh_asmc_jmp_iftnn_ofp_tw)-sizeof(void*))
+#define KNH_ASMC_JMP_IFN_ofp_SIZ  (sizeof(knh_asmc_jmp_ifn_ofp_tw)-sizeof(void*))
 
 /* ------------------------------------------------------------------------ */
 
@@ -1509,7 +1500,7 @@ typedef struct {
 	knhvm_addr_t a1;
 	knhvm_u1_t a3;
 	Object* a2;
-} knh_asmc_jmp_iftnn_oidx_t;
+} knh_asmc_jmp_ifn_oidx_t;
 
 typedef struct {
 	knhvm_opcode_t code;
@@ -1517,79 +1508,9 @@ typedef struct {
 	knhvm_u1_t a3;
 	Object* a2;
 	void *w;
-} knh_asmc_jmp_iftnn_oidx_tw;
+} knh_asmc_jmp_ifn_oidx_tw;
 
-#define KNH_ASMC_JMP_IFTNN_OIDX_SIZ  (sizeof(knh_asmc_jmp_iftnn_oidx_tw)-sizeof(void*))
-
-/* ------------------------------------------------------------------------ */
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_ebp_t a2;
-} knh_asmc_jmp_iffn_ebp_t;
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_ebp_t a2;
-	void *w;
-} knh_asmc_jmp_iffn_ebp_tw;
-
-#define KNH_ASMC_JMP_IFFN_ebp_SIZ  (sizeof(knh_asmc_jmp_iffn_ebp_tw)-sizeof(void*))
-
-/* ------------------------------------------------------------------------ */
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_sfp_t a2;
-} knh_asmc_jmp_iffn_sfp_t;
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_sfp_t a2;
-	void *w;
-} knh_asmc_jmp_iffn_sfp_tw;
-
-#define KNH_ASMC_JMP_IFFN_sfp_SIZ  (sizeof(knh_asmc_jmp_iffn_sfp_tw)-sizeof(void*))
-
-/* ------------------------------------------------------------------------ */
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_ofp_t a2;
-} knh_asmc_jmp_iffn_ofp_t;
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_ofp_t a2;
-	void *w;
-} knh_asmc_jmp_iffn_ofp_tw;
-
-#define KNH_ASMC_JMP_IFFN_ofp_SIZ  (sizeof(knh_asmc_jmp_iffn_ofp_tw)-sizeof(void*))
-
-/* ------------------------------------------------------------------------ */
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_u1_t a3;
-	Object* a2;
-} knh_asmc_jmp_iffn_oidx_t;
-
-typedef struct {
-	knhvm_opcode_t code;
-	knhvm_addr_t a1;
-	knhvm_u1_t a3;
-	Object* a2;
-	void *w;
-} knh_asmc_jmp_iffn_oidx_tw;
-
-#define KNH_ASMC_JMP_IFFN_OIDX_SIZ  (sizeof(knh_asmc_jmp_iffn_oidx_tw)-sizeof(void*))
+#define KNH_ASMC_JMP_IFN_OIDX_SIZ  (sizeof(knh_asmc_jmp_ifn_oidx_tw)-sizeof(void*))
 
 /* ------------------------------------------------------------------------ */
 
