@@ -59,7 +59,7 @@
 #define KONOHA_OS "macosx"
 #endif
 
-#ifdef KONOHA_OS__TBMX
+#ifdef KONOHA_OS__TB
 #define KONOHA_OS "teaboard"
 #endif
 
@@ -90,7 +90,7 @@
 		#endif
 		#ifdef TBMX1
 			#define KONOHA_OS  "teaboard"
-			#define KONOHA_OS__TBMX       1
+			#define KONOHA_OS__TB       1
 		#endif
 	#endif/*KONOHA_OS*/
 #endif/*__GNUC__*/
@@ -106,6 +106,7 @@
 		#define KONOHA_OS  "windows"
 		#define KONOHA_OS__WINDOWS
 	#endif
+#define _CRT_SECURE_NO_WARNINGS
 #endif  /* _MSC_VER */
 
 #ifndef KONOHA_OS
