@@ -76,6 +76,7 @@ static int knh_message_typedata[] = {
     /* KMSG_WARNING */ 0,
     /* KMSG_INFO */ 0,
     /* KMSG_ESYNTAX */ 1,
+    /* KMSG_EABORT */ 1,
     /* KMSG_EFORGET_PARENTHESIS */ 2,
     /* KMSG_EMISMATCH */ 1,
     /* KMSG_WUNCLOSED */ 2,
@@ -117,8 +118,6 @@ static int knh_message_typedata[] = {
     /* KMSG_NNCONST */ 1,
     /* KMSG_DUPCONST */ 1,
     /* KMSG_ENEXTPREV */ 1,
-    /* KMSG_EEMPTYEXPR */ 1,
-    /* KMSG_ETRINARY */ 1,
     /* KMSG_EBUILTINFUNC */ 1,
     /* KMSG_EPSTMT3 */ 1,
     /* KMSG_EPEACH */ 1,
@@ -162,6 +161,7 @@ static int knh_message_typedata[] = {
     /* KMSG_WNULL */ 2,
     /* KMSG_ETYPELET */ 1,
     /* KMSG_ETYPE */ 1,
+    /* KMSG_ETYPEBOOL */ 1,
     /* KMSG_WDUPFUNCNAME */ 2,
     /* KMSG_USCLASSFUNC */ 2,
     /* KMSG_IGNNTYPE */ 3,
@@ -250,19 +250,26 @@ static char* knh_message_data[] = {
     /* KMSG_ESYNTAX */ 
         /* en */ "Syntax Error",
 #ifdef KNH_USING_I18N
-        /* ja */ "文法的な間違いがあります（ただし、コンパイラのバグの可能性もあります）",
+        /* ja */ "文法的な間違いがあります",
 #endif
         "ESYNTAX",
     
-    /* KMSG_EFORGET_PARENTHESIS */ 
-        /* en */ "Syntax Error",
+    /* KMSG_EABORT */ 
+        /* en */ "Syntax Error. Otherwise, you'll find some compiler bugs.",
 #ifdef KNH_USING_I18N
-        /* ja */ "{の前で括弧を閉じ忘れています",
+        /* ja */ "文法的な間違いがあります（もしくは、コンパイラのバグかも知れません）",
+#endif
+        "EABORT",
+    
+    /* KMSG_EFORGET_PARENTHESIS */ 
+        /* en */ "You probably forget close",
+#ifdef KNH_USING_I18N
+        /* ja */ "たぶん括弧を閉じ忘れています",
 #endif
         "EFORGET_PARENTHESIS",
     
     /* KMSG_EMISMATCH */ 
-        /* en */ "Syntax Error",
+        /* en */ "Your forget close ()/{}/[]",
 #ifdef KNH_USING_I18N
         /* ja */ "括弧の対応をあわせてください",
 #endif
@@ -541,20 +548,6 @@ static char* knh_message_data[] = {
 #endif
         "ENEXTPREV",
     
-    /* KMSG_EEMPTYEXPR */ 
-        /* en */ "Give the right expression",
-#ifdef KNH_USING_I18N
-        /* ja */ "正しい式をあたえてください",
-#endif
-        "EEMPTYEXPR",
-    
-    /* KMSG_ETRINARY */ 
-        /* en */ "Syntax Error",
-#ifdef KNH_USING_I18N
-        /* ja */ "三項演算子のtrueとfalseの式はコロン(:)で区切ってください",
-#endif
-        "ETRINARY",
-    
     /* KMSG_EBUILTINFUNC */ 
         /* en */ "Invalid use of built-in function",
 #ifdef KNH_USING_I18N
@@ -856,6 +849,13 @@ static char* knh_message_data[] = {
 #endif
         "ETYPE",
     
+    /* KMSG_ETYPEBOOL */ 
+        /* en */ "Needs Boolean type",
+#ifdef KNH_USING_I18N
+        /* ja */ "Boolean型を与える必要があります",
+#endif
+        "ETYPEBOOL",
+    
     /* KMSG_WDUPFUNCNAME */ 
         /* en */ "Naming conflict occurs between functions",
 #ifdef KNH_USING_I18N
