@@ -867,7 +867,7 @@ void knh_Stmt_add_EXPTN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TEXPTN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TEXPTN);
 	}
 }
 
@@ -882,7 +882,7 @@ void knh_Stmt_add_NSNAME(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TNSNAME);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TNSNAME);
 	}
 }
 
@@ -897,7 +897,7 @@ void knh_Stmt_add_CURN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TCURN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TCURN);
 	}
 }
 
@@ -912,7 +912,7 @@ void knh_Stmt_add_NSCLASSN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TNSCLASSN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TNSCLASSN);
 	}
 }
 
@@ -927,7 +927,7 @@ void knh_Stmt_add_TYPEN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TTYPEN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TTYPEN);
 	}
 }
 
@@ -942,7 +942,7 @@ void knh_Stmt_add_METHODN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TMETHODN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TMETHODN);
 	}
 }
 
@@ -957,7 +957,7 @@ void knh_Stmt_add_FURN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TFURN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TFURN);
 	}
 }
 
@@ -972,7 +972,7 @@ void knh_Stmt_add_CLASSTN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TCLASSTN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TCLASSTN);
 	}
 }
 
@@ -987,7 +987,7 @@ void knh_Stmt_add_STR(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TSTR);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TSTR);
 	}
 }
 
@@ -1002,7 +1002,7 @@ void knh_Stmt_add_VARN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TVARN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TVARN);
 	}
 }
 
@@ -1017,7 +1017,7 @@ void knh_Stmt_add_CLASSN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TCLASSN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TCLASSN);
 	}
 }
 
@@ -1032,7 +1032,7 @@ void knh_Stmt_add_CMETHODN(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TCMETHODN);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TCMETHODN);
 	}
 }
 
@@ -1047,7 +1047,7 @@ void knh_Stmt_add_MT(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TMT);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TMT);
 	}
 }
 
@@ -1062,7 +1062,7 @@ void knh_Stmt_add_ANY(Ctx *ctx, Stmt *o, knh_tokens_t *tc)
 		tc->c += 1;
 	}
 	else {
-		knh_Stmt_perror(ctx, o, tc, KMSG_TANY);
+		knh_Stmt_tokens_perror(ctx, o, tc, KMSG_TANY);
 	}
 }
 
@@ -1149,7 +1149,6 @@ static Stmt *new_StmtRETURN(Ctx *ctx, knh_tokens_t *tc)
 	Stmt *o = new_Stmt(ctx, 0, STT_RETURN);
 	knh_StmtMETA_add_prestmt(ctx, o, tc, -2);
 	knh_Stmt_add_EXPRs(ctx, o, tc); /* EXPR* */
-	knh_Stmt_add_SEMICOLON(ctx, o, tc); /* ; */
 	return o;
 }
 
@@ -1163,7 +1162,6 @@ static Stmt *new_StmtMAPMAP(Ctx *ctx, knh_tokens_t *tc)
 	Stmt *o = new_Stmt(ctx, 0, STT_MAPMAP);
 	knh_StmtMETA_add_prestmt(ctx, o, tc, -2);
 	knh_Stmt_add_CLASSTNs(ctx, o, tc); /* CLASSTN* */
-	knh_Stmt_add_SEMICOLON(ctx, o, tc); /* ; */
 	return o;
 }
 
@@ -1712,7 +1710,7 @@ static int knh_stmt_array_isExpr[] = {
     0,  /* finally */ 
     0,  /* throw */ 
     0,  /* err */ 
-    0,  /* let */ 
+    1,  /* let */ 
     0,  /* letmulti */ 
     1,  /* new */ 
     1,  /* mapcast */ 
